## <span>Preparing for and Acing the Interview</span>

The interview process may seem daunting, but it allows for both you and the employer to determine if either of you are a perfect fit for each other. You can see it more of a bidirectional test as opposed to all the pressure being placed on you, the interviewee.

The purpose of the interview for an employer is to see if you’re the perfect fit, as mentioned, as well as truly get to know you and ask more detailed questions about anything, as you only have limited space to talk about yourself on a resume or a cover letter. This is also a time for you to truly demonstrate your mastery or proficiency in a skill.

As mentioned, the interview isn’t only for the employer, it’s also time for you to get to know more about the employer/company and determine if this job is truly something that suits you.

Most, if not all jobs, contain a portion known as the “Behavioural” interview. This is where you would talk about yourself, your interests, hobbies, the reason why you want this job, etc. This portion relies heavily on soft skills and you may need to practise with others to refine your skills.

For software development jobs, you may experience an additional portion known as the “Technical” interview. This is where your hard skills come in, and they’ll ask more specific questions about programming and computer science. You will also need to practise for this, which can be done alone as opposed to the behavioural portion which we recommend that you do with others.

Check out some of our advice below!

### General Advice

- Make sure you understand the question before you answer
  - It’s perfectly fine to ask the interviewer for further clarification or ask them to repeat themselves
  - It’s also fine, and highly recommended, that you slow down and take time to understand the question in full detail, rather than jumping ahead and answering
- Find the right balance for length in your responses
  - Your answers shouldn’t be too long nor should they be too short
  - Be precise and to the point
  - **DO NOT RAMBLE**
  - Be confident in what you say, and stand by what you say
    - It looks very bad if you keep backtracking and try to constantly reverse what you say
    - If you begin to doubt your answers, **slow down** and think things over
- Be friendly, professional, enthusiastic and show that you’re passionate
  - You want this job and the employer knows this
  - Remember! The interviewer wants you to succeed, so make it easier for them by being friendly and professional
- Research about the company beforehand
- Ask questions throughout and at the end of the interview (unless specified)
  - **ALWAYS BRING A QUESTION TO AN INTERVIEW**
    - If you begin to run out of time, you can exclude asking questions
    - Otherwise, it shows your interest in the position if you ask questions
  - Some safe general questions you can ask include:
    - What’s the work/team environment?
    - What type of projects will I be working on/have other interns worked on?
    - What do you like about (Company Name)?
    - What technologies/tools are used here?
    - Is this job remote, hybrid, or in-person?
    - When will I hear back about this job?
      - Don’t ask this question on WaterlooWorks unless it’s direct offer round, as you can refer to the co-op calendar with all the offer dates
    - What is the expected salary/compensation?
      - **ONLY ASK ON WATERLOOWORKS IF IT’S NOT SPECIFIED**
        - CCA not only protects you, but they also recommend you ask
      - Describe why you need to know, such as if it’s in-person and you need to consider living accommodations
      - Try to word it in such as way that you may be concerned about living conditions as opposed to greed
- Lastly, **go into the interview with the right mindset!**
  - More often than not, people walk into an interview being extremely nervous, which is valid but causes them to trip up and leads to the interview being less than ideal
  - Breathe! Stay relaxed and grounded
  - Whatever the outcome, this is another opportunity for you to practise your skills

### Behavioural

- There are tons of questions that you may face as part of the behavioural portion
  - This is where you demonstrate your passion, interest, and ability to adapt, learn, and grow
- You should be able to describe every portion of your resume in detail
  - More often than not, an interviewer may ask for a bit more clarification about a certain point on your resume
- We’ll cover a few of the common or trickiest questions, but there are a variety you can search up on the internet

### **“Tell me about/Introduce yourself”**

- This is the most common first question you will encounter at any interview
- Pitch/Sell yourself! Show all that’s great about you!
- Start by saying your name, your year, school, and program
- Talk about interests and hobbies, and tie them back to your interest and passion to the field
- Tell a very short story about yourself that allows the employer to see what drives you
  - Especially if you may lack some skills, being able to demonstrate your desire to learn and grow may be much more impactful
- Example: Hi! I’m FirstName and I’m a 3rd year Computer Science student at the University of Waterloo! Ever since I was a little kid, I’ve always been curious about the world and how it works, from how a simple click on my smartphone can result in me seeing someone on the other side of the world, which is what led me to start programming and end up here at the University of Waterloo studying computer science. I’ve always had this passion to learn more and contribute to something bigger, which is why I’m here looking to join Company Inc. as a software developer!

### **Behaviour-based question**

- This often comes in the form of “Describe a time when…” or “Tell me about a time when…” or “Give me an example of…”
- The reason why this type of question is used is to see how you tackle a past situation, which may potentially arise in the future, these often include:
  - Working under pressure
  - Working in a team, especially with conflicts or disagreements
  - Completing a task within a given deadline
  - Approaching a difficult situation
- To answer these questions, you should use the STAR Method, which can be used to model your answer with the following:
  - Situation
    - Provide the interviewer with context and background information about the situation you faced
    - Use the five Ws (Who, What, When, Where, Why, How)
  - Task
    - Describe what you needed to do, the goals you had, challenges you expected to face and any expectations of the task
  - Action
    - Describe what you did and how you did it in relation to tackling the task you mentioned
    - Highlight tools and skills you used
    - This should be the most extensive part of your answer
  - Result
    - Discuss the outcome of your actions, in relation to the task
    - Describe any accomplishments from your actions, and what you learnt as a result of your actions

### **Negative questions**

- These are questions that usually come in the form of:
  - “Tell me about a weakness you have.”
  - “What is one time you made a mistake?”
  - “Describe when you weren’t able to complete a task within a given deadline.”
- This question is not supposed to put you down, it’s more to test your ability to pull yourself out of a messy situation and be able to adapt, learn, and grow from adversity
- State the negative first, such as your weakness, then talk about how you’re using this weakness to learn and grow into something positive
- Avoid using certain answers that may be seen as more positive than negative or are too broad
  - Some answers that are frowned upon are being a perfectionist, being a workaholic, or public speaking

### Technical

- This is where all the hard skills you mentioned on your resume are truly tested, in addition to your critical thinking and problem solving skills
- Depending on the job you apply to, you may be asked questions ranging from something that is extremely concrete to something that is extremely conceptual
  - An example of a more concrete question would be “Demonstrate how you would call this API, which returns an array of objects, as a list in React?” or “Determine the number of prime numbers from 2 to N”
  - An example of a more conceptual question would be “Describe what a RESTful API is” or “What is the time complexity of deletion in an AVL tree”

#### **Concrete Questions**

- You will most likely encounter this type of technical question in your interview
- Read the question carefully, understand the full question and ask clarification questions about it before proceeding
  - People often skip important details in the question, which may change large parameters of the question
  - Slow down, get a full understanding, and ask the interviewer anything about the question, as they will fully understand the question and can answer any related questions that may cause you to get stuck
- If you’re given a choice of language, choose one that you’re most comfortable using
- Discuss your approach to the problem prior to beginning
- Wait until the interviewer says you can begin, as they may not have everything set up for you to do the question
- While you’re doing the question, **THINK OUT LOUD**
  - The interviewer is more concerned about the process as opposed to the answer
  - Even if you make mistakes in your code, if you voice your thoughts, the interviewer may spot errors that are silly mistakes (which may be penalised less than if they didn’t know)
  - This also allows the interviewer to help you if you get stuck
- Run some test cases and edges cases, and discuss those edge cases
- There are plenty of websites where you can practise and test yourself prior to the interview, such as LeetCode

#### **Conceptual Questions**

- A lot of these questions are trivia based, where you need extensive knowledge on a given technology, tool, framework, data structure, etc.
- Google is a good resource to go to for these types of questions, as there are a variety of questions that could be asked for your specific job
- Try your best to answer them to the best of your ability, and even if you’re unsure, it’s fine to make an educated guess
