## <span>Drafting your resume</span>

Your resume is the first thing an employer sees and the main thing that the employer will use to base their decision to interview you off of. You will need to make a good first impression to show that you’re the ideal candidate and that you have all the skills and qualifications necessary for the jobs you’re applying for.

Although anyone can state that they have the necessary qualifications and skills for a given job, you must demonstrate your ability through past experiences and/or projects, and describe them in detail to cement your skills.

### General Advice

- Follow the KISS principle
  - KISS - Keep it simple, stupid!
  - Often times, people try to cram in as much information, but being direct and straight to the point makes it easier to read
  - The employer, more often than not, has hundreds of resume to go through and may only have a few seconds to read through an entire resume, so simplicity is often preferred as extra details may be overlooked
- All the description you include on your resume should be short, simple, concise, and to the point
  - Make sure they’re relevant to the job posting
  - It’s common for descriptions to start with a verb
  - Highlight any metrics as it’s easy for people to understand
    - Bold these in your resume so they catch the attention of the employer

### Template and Styling

- There’s no one template to follow or one template you should use
  - There are countless templates you can find online, such as some on Overleaf, on Microsoft Word, etc.
  - Some people might want to try to “game the system” by optimising for ATS (Applicant Tracking Systems), but there’s no correct answer for this
- There’s no one text editing software to use
  - There’s a debate between using LaTeX as opposed to a WYSIWYG (What you see is what you get) word editor like Microsoft Word
  - Using one or the other may have slight advantages, but overall, they make no difference
  - The only answer is to use one that you’re comfortable using, as it’s just best to create something that someone can read
- You should use a **single** A4 or Letter page, and be able to fit everything on this one page
- Most people prefer to use narrow margins (1.27cm/0.5”) to fit everything in; however, it is safe to use normal margins (2.54cm/1”)
- Font selection is not much of a concern; however, keep it readable and professional
  - This means avoiding fonts such as Comic Sans
  - The argument between Sans Serif and Serif fonts doesn’t matter too much, readability matters the most
- Fill your page as much as you can!
  - Leaving empty space may leave a bad impression, as it may look like you may not be interested and it doesn’t give an employer enough information to base a decision off of
  - Look at the **Sections to Include** section for information to include that you may be missing
- If you’re running out of space on your page…
  - Decrease your font size (while maintaining readability)
    - So long as your page is readable, it’s perfectly fine to decrease your font size
    - Make sure it’s not **cramped** as it can be extremely difficult to distinguish multiple lines of text if the font is too small
    - There’s no definitive answer for the minimum size of font you can set, as fonts vary in size, but somewhere between 8pt and 10pt would be considered the bare minimum to be readable
  - Decrease spacing between text
  - Look out for lines that may only contain a few words
    - Some lines may break into multiple lines, with the last line that consist of only a few words
    - Try to rephrase that whole point such that it takes up less space, through the removal of some filler words, unnecessary adjectives/adverbs, etc.
  - Lastly, you may just have **too much information!**
    - You may be describing something in too much detail, may be mentioning too many projects/experiences, etc.
    - Don’t overwhelm the reader!
    - Remember, **quality > quantity!**

### Sections to Include

You should include the following sections in the following order

1. **Name and Contact Information**
2. **Skills**
3. **Experience and Employment History**
4. **Projects**
5. **Education**
6. **Awards and Certifications**
   If you’re applying externally (i.e. outside of the WaterlooWorks platform), then the education section should go above the Skills section

#### **Name and Contact Information**

- Put your full name in large and bold text!
- Include your contact information, primarily your phone number and email
  - People may argue that a phone number is not necessary; however, it’s not uncommon for an employer to contact you via phone, so it’s better to include it than not
  - For your email, ensure you include a professional looking email
    - The most safe option for your email is your school email
    - For University of Waterloo students, use your “Friendly Email Address”
      - E.g. firstname.lastname123@uwaterloo.ca
      - This can be set up at https://uwaterloo.ca/watiam
        - Login to your WatIAM
        - Click “Manage Email Address”
        - Select your “Friendly Email Address”
        - Click Submit
      - This makes it easier for a recruiter to remember your email and identify you based off your email
    - If you wish to use a personal email address as opposed to your school email, then your email should only consist of your full name, one or two additional symbols, and a few numbers
  - Include links to any of your portfolios and your LinkedIn
    - Your LinkedIn should utilise a custom Profile URL consisting of your full name as well, which makes it easier to access as opposed to a random assortment of characters
      - E.g. linkedin.com/in/firstname-lastname
    - Your main portfolio link to include would be your preferred Git repository website(s), such as GitHub or GitLab
    - And include any other additional portfolio pages that may be applicable to a job posting

#### **Skills**

- For software development jobs, you should only include hard skills such as languages, tools, frameworks, and libraries
  - Avoid including built-in libraries that are part of a programming language (such as the os library in Python), or API libraries (such as Discord.js)
- If you’re wondering if you know a skill well enough to put it on, think whether…
  - Worked with it during a co-op
  - You’ve done a project with it
  - Could answer questions on it if asked during an interview
  - You are comfortable with it?
  - If you’ve answered yes to these questions, then you should include it

#### **Experience and Employment History**

- You should ideally only include experiences and employment history that have some relevance to your desired industry
  - If you have other experiences, you may need to consider whether to include it as opposed to saving space for other sections
  - An example would be considering between mentioning an experience working in retail as opposed to a project you worked on during a hackathon
    - It may be preferable to include your project as opposed to your job experience if you begin to run out of space
- For all the experiences you list, mention the employer, your job title, the time that you worked in this position, and the location of this position
- Give a description of what you’ve done at this job, what languages/tools/libraries/frameworks you used, and you’ve accomplished
  - Highlight some of the things that you may have improved or any successes that occurred
- Some people may argue that you can include extracurriculars and volunteer experience
  - Only include it if you have skills and experience that are relevant to the job you’re applying to AND you don’t have other projects or experiences you can mention
- You should order your experiences/history from most recent to least recent

#### **Projects**

- Include a link to all your projects
- Mention everything you’ve used such as your language, frameworks, libraries, tools, etc.
  - It’s unnecessary to mention Git as a tool here, especially if you link to a Git repository
- Describe what was done, what you accomplished, any successes, etc.

#### **Education**

- Mention your degree(s), program(s) and specialisation(s)/option(s)
  - Example: Bachelor of Mathematics - Honours Computer Science Co-op (Bioinformatics Specialization), Combinatorics and Optimization
- Include your school and graduation date
  - Graduation date may not be applicable if you’re a first and second year as some jobs only give offers to third years and above
  - If you’re a University of Waterloo co-op student and plan to apply externally (outside of WaterlooWorks), then you should only state your planned graduation date as a regular graduation date as opposed to the co-op graduation date (4 years ahead as opposed to 5 years ahead in co-op)
- If you have a high average and GPA (average >=80% and GPA >=3.8), you should include them
  - If you don’t have a high average/GPA, it’s fine to exclude it
  - GPA is an iffy topic at Waterloo, due to the fact there’s no official conversion at Waterloo
  - If you’re a Waterloo student and wish to calculate your GPA, you can use the GPA conversion table from OUAC (Ontario Universities’ Application Centre) or an online converter
    - One website includes https://whatsmygpa.ca
    - You **convert** your overall average directly into GPA, you must convert the grade of each course into a GPA value then you can calculate an average from there
  - The main difference between a GPA and an average is GPA shows consistency in your performance as opposed to average which shows your overall performance
- Include some of the relevant courses to the jobs you’re applying to
  - If you’re a first/second year student, you may have difficulty with this; however, if you have partially completed a course and on track to complete it, it is generally safe to include it

#### **Awards and Certifications**

- This section is often excluded by many people, and depending on the jobs you’re applying for, you may also exclude this section
- You should avoid including common awards, such as the University of Waterloo President’s Scholarship
- Highlight the prestige of a given award, such as being in the top percentile of a given population
